@@ -1,6 +1,10 @@
+import random
 from pathlib import Path
 from typing import Generator
-import random
+
+from marshmallow.fields import Function
+
+from ps_typer.type_test.api import FactsApi
 
 # PATHS
 PROJECT_FOLDER = Path(__file__).absolute().parents[1]
@@ -94,7 +98,7 @@ COMMON_PHRASES = [
     "You can't make an omelet without breaking some eggs.",
 ]
 
-FACTS = [
+BACKUP_FACTS = [
     "There are more possible iterations of a game of chess than there are atoms in the known universe. There are also more ways to arrange a deck of cards than atoms in the known universe.",
     "Cleopatra lived closer in time to the Moon landing than to the construction of the Great Pyramid of Giza.",
     "It can take a photon 100,000 years to travel from the core of the sun to the surface, but only 8 minutes to travel the rest of the way to earth. This is due to the extreme density of the core of the Sun (150 times that of water).",
@@ -323,6 +327,15 @@ def get_random_choice(lst: list) -> Generator:
         yield text.strip()
 
 
+def get_random_text_from_api(fetch_random_text: Function, backup_text: list[str]):
+    backup_generator: Generator = get_random_choice(backup_text)
+
+    while True:
+        random_api_text: str | None = fetch_random_text()
+
+        yield random_api_text if random_api_text else next(backup_generator)
+
+
 def get_random_text(text_filename: Path, num_sentences: int) -> Generator:
     """
     Generator which yields a string of a given number of sentences from a given
@@ -347,14 +360,12 @@ def get_random_text(text_filename: Path, num_sentences: int) -> Generator:
 
 _translate = {
     "Common Phrases": lambda: get_random_choice(COMMON_PHRASES),
-    "Facts": lambda: get_random_choice(FACTS),
+    "Facts": lambda: get_random_text_from_api(FactsApi.get_random_fact, BACKUP_FACTS),
     "Famous Literature Excerpts": lambda: get_random_choice(LITERATURE_EXCERPTS),
     "Famous Quotes": lambda: get_random_choice(QUOTES),
     "Random Text: Brown": lambda: get_random_text(BROWN_TEXT, RANDOM_TEXT_SENTENCES),
     "Random Text: Gutenberg": lambda: get_random_text(
         GUTENBERG_TEXT, RANDOM_TEXT_SENTENCES
     ),
-    "Random Text: Webtext": lambda: get_random_text(
-        WEBTEXT_TEXT, RANDOM_TEXT_SENTENCES
-    ),
+    "Random Text: Webtext": lambda: get_random_text(WEBTEXT_TEXT, RANDOM_TEXT_SENTENCES),
 }
